<?php

declare(strict_types=1);

namespace Drupal\color_scheme_field\Plugin\Field\FieldType;

use Drupal\Core\Field\FieldItemBase;
use Drupal\Core\Field\FieldStorageDefinitionInterface;
use Drupal\Core\TypedData\DataDefinition;

/**
 * Plugin implementation of the 'Color Scheme Field' field type.
 *
 * @FieldType(
 *   id = "color_scheme_field",
 *   label = @Translation("Color Scheme"),
 *   module = "color_scheme_field",
 *   description = @Translation("Stores a color scheme name."),
 *   default_widget = "color_scheme_field_widget",
 *   default_formatter = NULL,
 * )
 */
class ColorSchemeItem extends FieldItemBase {

  /**
   * {@inheritdoc}
   */
  public static function schema(FieldStorageDefinitionInterface $field_definition) {
    return [
      'columns' => [
        'name' => [
          'type' => 'varchar',
          'length' => 255,
        ],
      ],
      'indexes' => [
        'format' => ['name'],
      ],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public static function propertyDefinitions(FieldStorageDefinitionInterface $field_definition) {
    $properties['name'] = DataDefinition::create('string')
      ->setLabel(t('Color Scheme'));

    return $properties;
  }

}
